@@ -17,23 +17,23 @@
 #' @import ggplot2
 #' @importFrom datamods import_modal import_server show_data
 #' @importFrom rlang expr sym
-esquisse_server <- function(id, 
+esquisse_server <- function(id,
                             data_rv = NULL,
                             default_aes = c("fill", "color", "size", "group", "facet"),
                             import_from = c("env", "file", "copypaste", "googlesheets")) {
-  
+
   moduleServer(
     id = id,
     module = function(input, output, session) {
       ns <- session$ns
       ggplotCall <- reactiveValues(code = "")
       data_chart <- reactiveValues(data = NULL, name = NULL)
-      
+
       # Settings modal (aesthetics choices)
       observeEvent(input$settings, {
         showModal(modal_settings(aesthetics = input$aesthetics))
       })
-      
+
       # Generate drag-and-drop input
       output$ui_aesthetics <- renderUI({
         if (is.reactive(default_aes)) {
@@ -78,12 +78,12 @@ esquisse_server <- function(id,
           )
         }
       })
-      
+
       observeEvent(data_rv$data, {
         data_chart$data <- data_rv$data
         data_chart$name <- data_rv$name
       }, ignoreInit = FALSE)
-      
+
       # Launch import modal if no data at start
       if (is.null(isolate(data_rv$data))) {
         datamods::import_modal(
@@ -92,7 +92,7 @@ esquisse_server <- function(id,
           title = i18n("Import data to create a graph")
         )
       }
-      
+
       # Launch import modal if button clicked
       observeEvent(input$launch_import_data, {
         datamods::import_modal(
@@ -101,7 +101,7 @@ esquisse_server <- function(id,
           title = i18n("Import data to create a graph")
         )
       })
-      
+
       # Data imported and update rv used
       data_imported_r <- datamods::import_server("import-data", return_class = "tbl_df")
       observeEvent(data_imported_r$data(), {
@@ -109,7 +109,7 @@ esquisse_server <- function(id,
         data_chart$data <- data
         data_chart$name <- data_imported_r$name() %||% "imported_data"
       })
-      
+
       observeEvent(input$show_data, {
         data <- controls_rv$data
         if (!is.data.frame(data)) {
@@ -123,7 +123,7 @@ esquisse_server <- function(id,
           datamods::show_data(data, title = i18n("Dataset"), type = "modal")
         }
       })
-      
+
       # Update drag-and-drop input when data changes
       observeEvent(data_chart$data, {
         data <- data_chart$data
@@ -154,7 +154,7 @@ esquisse_server <- function(id,
           )
         }
       }, ignoreNULL = FALSE)
-      
+
       geom_possible <- reactiveValues(x = "auto")
       geom_controls <- reactiveValues(x = "auto")
       observeEvent(list(input$dragvars$target, input$geom), {
@@ -167,19 +167,19 @@ esquisse_server <- function(id,
           )
         )
         geom_possible$x <- c("auto", geoms)
-        
+
         geom_controls$x <- select_geom_controls(input$geom, geoms)
-        
+
         if (!is.null(input$dragvars$target$fill) | !is.null(input$dragvars$target$color)) {
           geom_controls$palette <- TRUE
         } else {
           geom_controls$palette <- FALSE
         }
       }, ignoreInit = TRUE)
-      
+
       observeEvent(geom_possible$x, {
         geoms <- c(
-          "auto", "line", "area", "bar", "histogram",
+          "auto", "line", "area", "bar", "col", "histogram",
           "point", "jitter", "boxplot", "violin", "density",
           "tile", "sf"
         )
@@ -190,7 +190,7 @@ esquisse_server <- function(id,
           disabled = setdiff(geoms, geom_possible$x)
         )
       })
-      
+
       # Module chart controls : title, xlabs, colors, export...
       # paramsChart <- reactiveValues(inputs = NULL)
       controls_rv <- controls_server(
@@ -228,47 +228,48 @@ esquisse_server <- function(id,
           )
         })
       )
-      
-      
+
+
       render_ggplot("plooooooot", {
+        req(input$play_plot, cancelOutput = TRUE)
         req(data_chart$data)
         req(controls_rv$data)
         req(controls_rv$inputs)
         req(input$geom)
-        
+
         aes_input <- make_aes(input$dragvars$target)
-        
+
         req(unlist(aes_input) %in% names(data_chart$data))
-        
+
         mapping <- build_aes(
           data = data_chart$data,
           .list = aes_input,
           geom = input$geom
         )
-        
+
         geoms <- potential_geoms(
           data = data_chart$data,
           mapping = mapping
         )
         req(input$geom %in% geoms)
-        
+
         data <- controls_rv$data
-        
+
         scales <- which_pal_scale(
           mapping = mapping,
           palette = controls_rv$colors$colors,
           data = data,
           reverse = controls_rv$colors$reverse
         )
-        
+
         if (identical(input$geom, "auto")) {
           geom <- "blank"
         } else {
           geom <- input$geom
         }
-        
+
         geom_args <- match_geom_args(input$geom, controls_rv$inputs, mapping = mapping)
-        
+
         if (isTRUE(controls_rv$smooth$add) & input$geom %in% c("point", "line")) {
           geom <- c(geom, "smooth")
           geom_args <- c(
@@ -282,14 +283,14 @@ esquisse_server <- function(id,
             setNames(list(geom_args), input$geom),
             list(jitter = controls_rv$jitter$args)
           )
-          
+
         }
         if (!is.null(aes_input$ymin) & !is.null(aes_input$ymax) & input$geom %in% c("line")) {
           geom <- c("ribbon", geom)
           mapping_ribbon <- aes_input[c("ymin", "ymax")]
           geom_args <- c(
             list(ribbon = list(
-              mapping = expr(aes(!!!syms2(mapping_ribbon))), 
+              mapping = expr(aes(!!!syms2(mapping_ribbon))),
               fill = controls_rv$inputs$color_ribbon
             )),
             setNames(list(geom_args), input$geom)
@@ -297,20 +298,20 @@ esquisse_server <- function(id,
           mapping$ymin <- NULL
           mapping$ymax <- NULL
         }
-        
+
         scales_args <- scales$args
         scales <- scales$scales
-        
+
         if (isTRUE(controls_rv$transX$use)) {
           scales <- c(scales, "x_continuous")
           scales_args <- c(scales_args, list(x_continuous = controls_rv$transX$args))
         }
-        
+
         if (isTRUE(controls_rv$transY$use)) {
           scales <- c(scales, "y_continuous")
           scales_args <- c(scales_args, list(y_continuous = controls_rv$transY$args))
         }
-        
+
         if (isTRUE(controls_rv$limits$x)) {
           xlim <- controls_rv$limits$xlim
         } else {
@@ -340,7 +341,7 @@ esquisse_server <- function(id,
           xlim = xlim,
           ylim = ylim
         )
-        
+
         ggplotCall$code <- deparse2(gg_call)
         ggplotCall$call <- gg_call
 
@@ -350,11 +351,11 @@ esquisse_server <- function(id,
         )
         ggplotCall$ggobj$plot
       }, filename = "esquisse-plot")
-      
-      
+
+
       # Close addin
       observeEvent(input$close, shiny::stopApp())
-      
+
       # Ouput of module (if used in Shiny)
       output_module <- reactiveValues(code_plot = NULL, code_filters = NULL, data = NULL)
       observeEvent(ggplotCall$code, {
@@ -364,9 +365,9 @@ esquisse_server <- function(id,
         output_module$code_filters <- controls_rv$code
         output_module$data <- controls_rv$data
       }, ignoreInit = TRUE)
-      
+
       return(output_module)
     }
   )
-  
+
 }
