@@ -36,33 +36,65 @@ test_that("search_obj works", {
 
   e <- new.env()
 
-  no_df <- esquisse:::search_obj(env = e)
+  no_df <- search_obj(env = e)
   expect_null(no_df)
 
   data("economics", package = "ggplot2")
   assign("economics", economics, envir = e)
-  one_df <- esquisse:::search_obj(env = e)
+  one_df <- search_obj(env = e)
   expect_length(one_df, 1)
 
   assign("my_vec", 1:10, envir = e)
-  still_one_df <- esquisse:::search_obj(env = e)
+  still_one_df <- search_obj(env = e)
   expect_length(still_one_df, 1)
 
 })
 
 
 
-test_that("col_type works", {
+test_that("col_type return appropriate type", {
 
-  discrete <- esquisse:::col_type(x = letters)
+  discrete <- col_type(x = letters)
   expect_identical(discrete, "discrete")
 
-  id <- esquisse:::col_type(x = as.character(1:100))
+  id <- col_type(x = as.character(1:100))
   expect_identical(id, "id")
 
-  continuous <- esquisse:::col_type(x = rnorm(10))
+  continuous <- col_type(x = rnorm(10))
   expect_identical(continuous, "continuous")
+  
+  date <- col_type(x = Sys.Date() + 1:10)
+  expect_identical(date, "time")
 
 })
 
 
+test_that("col_type works with different object type", {
+  
+  DF <- col_type(x = iris)
+  expect_length(DF, ncol(iris))
+  
+  DF1 <- col_type(x = iris[1, ])
+  expect_length(DF1, ncol(iris))
+  
+  DF2 <- col_type(x = iris[, 3, drop = FALSE])
+  expect_length(DF2, 1)
+  
+  LIST <- col_type(x = as.list(iris))
+  expect_length(LIST, ncol(iris))
+  
+})
+
+
+test_that("makeId & idToChar works", {
+  
+  expect_null(makeId(NULL))
+  expect_null(makeId(character(0)))
+  
+  expect_length(makeId(names(iris)), length(names(iris)))
+  
+  expect_identical(idToChar(makeId(names(iris))), names(iris))
+  
+})
+
+
